@@ -5,6 +5,7 @@
 #ifdef __cplusplus
 #include <iostream>
 #include <string>
+#include <glib.h>
 
 using namespace std;
 
@@ -19,17 +20,19 @@ public:
 	~ProfileManager();
 	
 	// Login with certain userID
-	bool Login(int userId);
+	gboolean Login(guint32 userId);
 	// Logout
-	bool Logout();
+	gboolean Logout();
 	// Show user details
 	string ViewDetails();
 	// Get single detail
 	string ViewDetail(string& detail);
 	// Edit own details
-	bool EditDetails(string& detail, string& newValue);
+	gboolean EditDetails(string& detail, string& newValue);
 	// Push another user to service
-	bool ForceUser(int userID);
+	gboolean ForceUser(guint32 userID);
+	// Get id
+	guint32 GetId();
 
 private:
 	
@@ -40,7 +43,7 @@ private:
 	static ProfileManager* iInstance;
 	StorageAgent *iStorageAgent;
 	//ProcessAgent *iProcessAgent;
-	int iUser;
+	guint32 iUser;
 };
 
 #else
@@ -64,7 +67,7 @@ void log_wrap(char* msg, int info);
  *
  * Use the struct only through functions described here!
  */
-ProfileManager* gems_profilemanager_new_manager();
+ProfileManager* profilemanager_new_manager();
 
 
 /* Delete profile manager
@@ -74,7 +77,7 @@ ProfileManager* gems_profilemanager_new_manager();
  * Params:
  *  ProfileManager* _aManager - object to be destroyed
  */ 
-void gems_profilemanager_delete_manager(ProfileManager* _aManager);
+void profilemanager_delete_manager(ProfileManager* _aManager);
 
 
 /* Login to ProfileManager
@@ -87,7 +90,7 @@ void gems_profilemanager_delete_manager(ProfileManager* _aManager);
  *
  * Returns: int, 0 if false, 1 if true
  */
-int gems_profilemanager_login(ProfileManager* _aManager, int _userId);
+gboolean profilemanager_login(ProfileManager* _aManager, guint32 _userId);
 
 
 /* Login to ProfileManager
@@ -99,7 +102,7 @@ int gems_profilemanager_login(ProfileManager* _aManager, int _userId);
  *
  * Returns: int, 0 if false, 1 if true
  */
-int gems_profilemanager_logout(ProfileManager* _aManager);
+gboolean profilemanager_logout(ProfileManager* _aManager);
 
 
 /* View a single detail
@@ -112,8 +115,8 @@ int gems_profilemanager_logout(ProfileManager* _aManager);
  *
  * Returns: char* containing the value, or empty if not found
  */
-const char* gems_profilemanager_view_info(ProfileManager* _aManager,
-	char* _parameter);
+const gchar* profilemanager_view_info(ProfileManager* _aManager,
+	gchar* _parameter);
 
 
 /* Edit own detail
@@ -127,45 +130,46 @@ const char* gems_profilemanager_view_info(ProfileManager* _aManager,
  *
  * Returns: int, 0 - detail was not found, 1 - detail was found (val. changed)
  */
-int gems_profilemanager_edit_info(ProfileManager* _aManager, char* _parameter,
-	char* _value);
+gboolean profilemanager_edit_info(ProfileManager* _aManager, gchar* _parameter,
+	gchar* _value);
 
+guint32 profilemanager_get_userid(ProfileManager* _aManager);
 
 /* Get own username */
-const char* gems_profilemanager_get_username(ProfileManager* _aManager);
+const gchar* profilemanager_get_username(ProfileManager* _aManager);
 
 /* Get firstname */
-const char* gems_profilemanager_get_firstname(ProfileManager* _aManager);
+const gchar* profilemanager_get_firstname(ProfileManager* _aManager);
 
 /* Get lastname */
-const char* gems_profilemanager_get_lastname(ProfileManager* _aManager);
+const gchar* profilemanager_get_lastname(ProfileManager* _aManager);
 
 /* Get age */
-const char* gems_profilemanager_get_age(ProfileManager* _aManager);
+guint16 profilemanager_get_age(ProfileManager* _aManager);
 
 /* Get points */
-unsigned int gems_profilemanager_get_points(ProfileManager* _aManager);
+guint32 profilemanager_get_points(ProfileManager* _aManager);
 
 /* Set own username */
-int gems_profilemanager_set_username(ProfileManager* _aManager, char* _value);
+gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value);
 
 /* Set firstname */
-int gems_profilemanager_set_firstname(ProfileManager* _aManager, char* _value);
+gboolean profilemanager_set_firstname(ProfileManager* _aManager, gchar* _value);
 
 /* Set lastname */
-int gems_profilemanager_set_lastname(ProfileManager* _aManager, char* _value);
+gboolean profilemanager_set_lastname(ProfileManager* _aManager, gchar* _value);
 
 /* Set age - limit is 120 */
-int gems_profilemanager_set_age(ProfileManager* _aManager, unsigned int _value);
+gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value);
 
 /* Add points */
-int gems_profilemanager_add_points(ProfileManager* _aManager, unsigned int _value);
+gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value);
 
 /* Remove points */
-int gems_profilemanager_remove_points(ProfileManager* _aManager, unsigned int _value);
+gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value);
 
 /* Reset points (set to zero) */
-void gems_profilemanager_reset_points(ProfileManager* _aManager);
+void profilemanager_reset_points(ProfileManager* _aManager);
 
 #ifdef __cplusplus
 }
